==> octave-epstk_1.9.orig.tar.gz: octave-epstk-1.9/m/esavpar.m <==
oPath=ePath;
oGhostview=eGhostview;
oGhostscript=eGhostscript;
oFileName=eFileName;
oFile=eFile;
oUserUnit=eUserUnit;
oFac=eFac;
oFonts=eFonts;
oColorMaps=eColorMaps;
oPageWidth=ePageWidth;
oPageHeight=ePageHeight;
oPageOrientation=ePageOrientation;
oXScaleFac=eXScaleFac;
oYScaleFac=eYScaleFac;
oWinOrigin=eWinOrigin;
oWinWidth=eWinWidth;
oWinHeight=eWinHeight;
oWinFrameVisible=eWinFrameVisible;
oWinFrameLineWidth=eWinFrameLineWidth;
oWinTimeStampVisible=eWinTimeStampVisible;
oWinTimeStampFont=eWinTimeStampFont;
oWinTimeStampFontSize=eWinTimeStampFontSize;
oPlotAreaPos=ePlotAreaPos;
oPlotAreaWidth=ePlotAreaWidth;
oPlotAreaHeight=ePlotAreaHeight;
oPlotAreaXValueStart=ePlotAreaXValueStart;
oPlotAreaXValueEnd=ePlotAreaXValueEnd;
oPlotAreaYValueStart=ePlotAreaYValueStart;
oPlotAreaYValueEnd=ePlotAreaYValueEnd;
oPolarPlotAreaCenterPos=ePolarPlotAreaCenterPos;
oPolarPlotAreaRadMin=ePolarPlotAreaRadMin;
oPolarPlotAreaRadMax=ePolarPlotAreaRadMax;
oPolarPlotAreaAngStart=ePolarPlotAreaAngStart;
oPolarPlotAreaAngEnd=ePolarPlotAreaAngEnd;
oPolarPlotAreaValStart=ePolarPlotAreaValStart;
oPolarPlotAreaValEnd=ePolarPlotAreaValEnd;
oPlotTitleDistance=ePlotTitleDistance;
oPlotTitleFontSize=ePlotTitleFontSize;
oPlotTitleText=ePlotTitleText;
oPlotTitleTextFont=ePlotTitleTextFont;
oAxesColor=eAxesColor;
oAxesLineWidth=eAxesLineWidth;
oAxesTicShortLength=eAxesTicShortLength;
oAxesTicLongLength=eAxesTicLongLength;
oAxesTicLongMaxN=eAxesTicLongMaxN;
oAxesValueSpace=eAxesValueSpace;
oAxesValueFontSize=eAxesValueFontSize;
oAxesLabelFontSize=eAxesLabelFontSize;
oAxesLabelTextFont=eAxesLabelTextFont;
oAxesCrossOrigin=eAxesCrossOrigin;
oXGridLineWidth=eXGridLineWidth;
oXGridColor=eXGridColor;
oXGridDash=eXGridDash;
oXGridVisible=eXGridVisible;
oYGridLineWidth=eYGridLineWidth;
oYGridColor=eYGridColor;
oYGridDash=eYGridDash;
oYGridVisible=eYGridVisible;
oPolarRadiusGridLineWidth=ePolarRadiusGridLineWidth;
oPolarRadiusGridColor=ePolarRadiusGridColor;
oPolarRadiusGridDash=ePolarRadiusGridDash;
oPolarRadiusGridVisible=ePolarRadiusGridVisible;
oPolarAngleGridLineWidth=ePolarAngleGridLineWidth;
oPolarAngleGridColor=ePolarAngleGridColor;
oPolarAngleGridDash=ePolarAngleGridDash;
oPolarAngleGridVisible=ePolarAngleGridVisible;
oXAxisSouthScale=eXAxisSouthScale;
oXAxisSouthScaleType=eXAxisSouthScaleType;
oXAxisSouthValueFormat=eXAxisSouthValueFormat;
oXAxisSouthValueVisible=eXAxisSouthValueVisible;
oXAxisSouthLabelDistance=eXAxisSouthLabelDistance;
oXAxisSouthLabelText=eXAxisSouthLabelText;
oXAxisSouthVisible=eXAxisSouthVisible;
oXAxisNorthScale=eXAxisNorthScale;
oXAxisNorthScaleType=eXAxisNorthScaleType;
oXAxisNorthValueFormat=eXAxisNorthValueFormat;
oXAxisNorthValueVisible=eXAxisNorthValueVisible;
oXAxisNorthLabelDistance=eXAxisNorthLabelDistance;
oXAxisNorthLabelText=eXAxisNorthLabelText;
oXAxisNorthVisible=eXAxisNorthVisible;
oYAxisWestScale=eYAxisWestScale;
oYAxisWestScaleType=eYAxisWestScaleType;
oYAxisWestValueFormat=eYAxisWestValueFormat;
oYAxisWestValueVisible=eYAxisWestValueVisible;
oYAxisWestLabelDistance=eYAxisWestLabelDistance;
oYAxisWestLabelText=eYAxisWestLabelText;
oYAxisWestVisible=eYAxisWestVisible;
oYAxisEastScale=eYAxisEastScale;
oYAxisEastScaleType=eYAxisEastScaleType;
oYAxisEastValueFormat=eYAxisEastValueFormat;
oYAxisEastValueVisible=eYAxisEastValueVisible;
oYAxisEastLabelDistance=eYAxisEastLabelDistance;
oYAxisEastLabelText=eYAxisEastLabelText;
oYAxisEastVisible=eYAxisEastVisible;
oPolarAxisRadScale=ePolarAxisRadScale;
oPolarAxisRadValueFormat=ePolarAxisRadValueFormat;
oPolarAxisRadValueVisible=ePolarAxisRadValueVisible;
oPolarAxisRadVisible=ePolarAxisRadVisible;
oPolarAxisAngScale=ePolarAxisAngScale;
oPolarAxisAngValueFormat=ePolarAxisAngValueFormat;
oPolarAxisAngValueVisible=ePolarAxisAngValueVisible;
oPolarAxisAngVisible=ePolarAxisAngVisible;
oPlotLineNr=ePlotLineNr;
oPolarPlotLineNr=ePolarPlotLineNr;
oPlotLineColor=ePlotLineColor;
oPlotLineDash=ePlotLineDash;
oPlotLineWidth=ePlotLineWidth;
oPlotLineInterpolation=ePlotLineInterpolation;
oPlotLegendPos=ePlotLegendPos;
oPlotLegendFontSize=ePlotLegendFontSize;
oPlotLegendDistance=ePlotLegendDistance;
oPlotLegendTextFont=ePlotLegendTextFont;
oImageDefaultColorMap=eImageDefaultColorMap;
oImageFrameVisible=eImageFrameVisible;
oImageLegendPos=eImageLegendPos;
oImageLegendWidth=eImageLegendWidth;
oImageLegendHeight=eImageLegendHeight;
oImageLegendScale=eImageLegendScale;
oImageLegendValueFormat=eImageLegendValueFormat;
oImageLegendValueVisible=eImageLegendValueVisible;
oImageLegendLabelDistance=eImageLegendLabelDistance;
oImageLegendLabelText=eImageLegendLabelText;
oImageLegendVisible=eImageLegendVisible;
oParamPos=eParamPos;
oParamFontSize=eParamFontSize;
oParamLineDistance=eParamLineDistance;
oParamTextValueDistance=eParamTextValueDistance;
oParamText=eParamText;
oParamTextFont=eParamTextFont;
oParamValue=eParamValue;
oParamValueFont=eParamValueFont;
oLineWidth=eLineWidth;
oLineColor=eLineColor;
oLineDash=eLineDash;
oTextFont=eTextFont;
oTextFontSize=eTextFontSize;
oTextPos=eTextPos;
oTextColor=eTextColor;
oTextAlignment=eTextAlignment;
oTextRotation=eTextRotation;
oContourLineWidth=eContourLineWidth;
oContourLineColor=eContourLineColor;
oContourLineDash=eContourLineDash;
oContourScale=eContourScale;
oContourValueVisible=eContourValueVisible;
oContourValueFormat=eContourValueFormat;
oContourValueFont=eContourValueFont;
oContourValueFontSize=eContourValueFontSize;
oContourValueDistance=eContourValueDistance;
oContourLevelsMaxN=eContourLevelsMaxN;
oTabBackgroundColor=eTabBackgroundColor;
oTabFrameVisible=eTabFrameVisible;
oTabFrameLineWidth=eTabFrameLineWidth;
oTabFrameColor=eTabFrameColor;
oTabFrameDash=eTabFrameDash;
oTabXLineVisible=eTabXLineVisible;
oTabXLineWidth=eTabXLineWidth;
oTabXLineColor=eTabXLineColor;
oTabXLineDash=eTabXLineDash;
oTabYLineVisible=eTabYLineVisible;
oTabYLineWidth=eTabYLineWidth;
oTabYLineColor=eTabYLineColor;
oTabYLineDash =eTabYLineDash ;

==> octave-epstk_2.0.orig.tar.gz: octave-epstk-2.0/m/esavpar.m <==
oPath=ePath;
oGhostview=eGhostview;
oGhostscript=eGhostscript;
oFileName=eFileName;
oFile=eFile;
oUserUnit=eUserUnit;
oFac=eFac;
oFonts=eFonts;
oColorMaps=eColorMaps;
oPageWidth=ePageWidth;
oPageHeight=ePageHeight;
oPageOrientation=ePageOrientation;
oPageReflection=ePageReflection;
oXScaleFac=eXScaleFac;
oYScaleFac=eYScaleFac;
oWinWidth=eWinWidth;
oWinHeight=eWinHeight;
oWinFrameVisible=eWinFrameVisible;
oWinFrameLineWidth=eWinFrameLineWidth;
oWinTimeStampVisible=eWinTimeStampVisible;
oWinTimeStampFont=eWinTimeStampFont;
oWinTimeStampFontSize=eWinTimeStampFontSize;
oPlotAreaPos=ePlotAreaPos;
oPlotAreaWidth=ePlotAreaWidth;
oPlotAreaHeight=ePlotAreaHeight;
oPlotAreaXValueStart=ePlotAreaXValueStart;
oPlotAreaXValueEnd=ePlotAreaXValueEnd;
oPlotAreaYValueStart=ePlotAreaYValueStart;
oPlotAreaYValueEnd=ePlotAreaYValueEnd;
oPolarPlotAreaCenterPos=ePolarPlotAreaCenterPos;
oPolarPlotAreaRadMin=ePolarPlotAreaRadMin;
oPolarPlotAreaRadMax=ePolarPlotAreaRadMax;
oPolarPlotAreaAngStart=ePolarPlotAreaAngStart;
oPolarPlotAreaAngEnd=ePolarPlotAreaAngEnd;
oPolarPlotAreaValStart=ePolarPlotAreaValStart;
oPolarPlotAreaValEnd=ePolarPlotAreaValEnd;
oPlotTitleDistance=ePlotTitleDistance;
oPlotTitleFontSize=ePlotTitleFontSize;
oPlotTitleText=ePlotTitleText;
oPlotTitleTextFont=ePlotTitleTextFont;
oAxesColor=eAxesColor;
oAxesLineWidth=eAxesLineWidth;
oAxesTicShortLength=eAxesTicShortLength;
oAxesTicLongLength=eAxesTicLongLength;
oAxesTicLongMaxN=eAxesTicLongMaxN;
oAxesValueSpace=eAxesValueSpace;
oAxesValueFontSize=eAxesValueFontSize;
oAxesLabelFontSize=eAxesLabelFontSize;
oAxesLabelTextFont=eAxesLabelTextFont;
oAxesCrossOrigin=eAxesCrossOrigin;
oXGridLineWidth=eXGridLineWidth;
oXGridColor=eXGridColor;
oXGridDash=eXGridDash;
oXGridVisible=eXGridVisible;
oYGridLineWidth=eYGridLineWidth;
oYGridColor=eYGridColor;
oYGridDash=eYGridDash;
oYGridVisible=eYGridVisible;
oPolarRadiusGridLineWidth=ePolarRadiusGridLineWidth;
oPolarRadiusGridColor=ePolarRadiusGridColor;
oPolarRadiusGridDash=ePolarRadiusGridDash;
oPolarRadiusGridVisible=ePolarRadiusGridVisible;
oPolarAngleGridLineWidth=ePolarAngleGridLineWidth;
oPolarAngleGridColor=ePolarAngleGridColor;
oPolarAngleGridDash=ePolarAngleGridDash;
oPolarAngleGridVisible=ePolarAngleGridVisible;
oXAxisSouthScale=eXAxisSouthScale;
oXAxisSouthScaleType=eXAxisSouthScaleType;
oXAxisSouthValueFormat=eXAxisSouthValueFormat;
oXAxisSouthValueVisible=eXAxisSouthValueVisible;
oXAxisSouthValuePos=eXAxisSouthValuePos;
oXAxisSouthLabelDistance=eXAxisSouthLabelDistance;
oXAxisSouthLabelText=eXAxisSouthLabelText;
oXAxisSouthVisible=eXAxisSouthVisible;
oXAxisNorthScale=eXAxisNorthScale;
oXAxisNorthScaleType=eXAxisNorthScaleType;
oXAxisNorthValueFormat=eXAxisNorthValueFormat;
oXAxisNorthValueVisible=eXAxisNorthValueVisible;
oXAxisNorthValuePos=eXAxisNorthValuePos;
oXAxisNorthLabelDistance=eXAxisNorthLabelDistance;
oXAxisNorthLabelText=eXAxisNorthLabelText;
oXAxisNorthVisible=eXAxisNorthVisible;
oYAxisWestScale=eYAxisWestScale;
oYAxisWestScaleType=eYAxisWestScaleType;
oYAxisWestValueFormat=eYAxisWestValueFormat;
oYAxisWestValueVisible=eYAxisWestValueVisible;
oYAxisWestValuePos=eYAxisWestValuePos;
oYAxisWestLabelDistance=eYAxisWestLabelDistance;
oYAxisWestLabelText=eYAxisWestLabelText;
oYAxisWestVisible=eYAxisWestVisible;
oYAxisEastScale=eYAxisEastScale;
oYAxisEastScaleType=eYAxisEastScaleType;
oYAxisEastValueFormat=eYAxisEastValueFormat;
oYAxisEastValueVisible=eYAxisEastValueVisible;
oYAxisEastValuePos=eYAxisEastValuePos;
oYAxisEastLabelDistance=eYAxisEastLabelDistance;
oYAxisEastLabelText=eYAxisEastLabelText;
oYAxisEastVisible=eYAxisEastVisible;
oPieSliceNo=ePieSliceNo;
oPolarAxisRadScale=ePolarAxisRadScale;
oPolarAxisRadScaleType=ePolarAxisRadScaleType;
oPolarAxisRadValueFormat=ePolarAxisRadValueFormat;
oPolarAxisRadValueVisible=ePolarAxisRadValueVisible;
oPolarAxisRadValuePos=ePolarAxisRadValuePos;
oPolarAxisRadVisible=ePolarAxisRadVisible;
oPolarAxisAngScale=ePolarAxisAngScale;
oPolarAxisAngValueFormat=ePolarAxisAngValueFormat;
oPolarAxisAngValueVisible=ePolarAxisAngValueVisible;
oPolarAxisAngValueAngle=ePolarAxisAngValueAngle;
oPolarAxisAngVisible=ePolarAxisAngVisible;
oPlotLineNo=ePlotLineNo;
oPolarPlotLineNo=ePolarPlotLineNo;
oPlotLineColor=ePlotLineColor;
oPlotLineDash=ePlotLineDash;
oPlotLineWidth=ePlotLineWidth;
oPlotLineInterpolation=ePlotLineInterpolation;
oPlotLegendPos=ePlotLegendPos;
oPlotLegendFontSize=ePlotLegendFontSize;
oPlotLegendDistance=ePlotLegendDistance;
oPlotLegendTextFont=ePlotLegendTextFont;
oImageDefaultColorMap=eImageDefaultColorMap;
oImageFrameVisible=eImageFrameVisible;
oImageLegendPos=eImageLegendPos;
oImageLegendWidth=eImageLegendWidth;
oImageLegendHeight=eImageLegendHeight;
oImageLegendScale=eImageLegendScale;
oImageLegendScaleType=eImageLegendScaleType;
oImageLegendValueFormat=eImageLegendValueFormat;
oImageLegendValueVisible=eImageLegendValueVisible;
oImageLegendValuePos=eImageLegendValuePos;
oImageLegendLabelDistance=eImageLegendLabelDistance;
oImageLegendLabelText=eImageLegendLabelText;
oImageLegendVisible=eImageLegendVisible;
oParamPos=eParamPos;
oParamFontSize=eParamFontSize;
oParamLineDistance=eParamLineDistance;
oParamTextValueDistance=eParamTextValueDistance;
oParamText=eParamText;
oParamTextFont=eParamTextFont;
oParamValue=eParamValue;
oParamValueFont=eParamValueFont;
oLineWidth=eLineWidth;
oLineColor=eLineColor;
oLineDash=eLineDash;
oTextFont=eTextFont;
oTextFontSize=eTextFontSize;
oTextPos=eTextPos;
oTextColor=eTextColor;
oTextAlignment=eTextAlignment;
oTextRotation=eTextRotation;
oTextLimitWord=eTextLimitWord;
oTextLimitPara=eTextLimitPara;
oTextBoxFeedLine=eTextBoxFeedLine;
oTextBoxFeedPara=eTextBoxFeedPara;
oTextBoxSpaceNorth=eTextBoxSpaceNorth;
oTextBoxSpaceSouth=eTextBoxSpaceSouth;
oTextBoxSpaceWest=eTextBoxSpaceWest;
oTextBoxSpaceEast=eTextBoxSpaceEast;
oContourLineWidth=eContourLineWidth;
oContourLineColor=eContourLineColor;
oContourLineDash=eContourLineDash;
oContourScale=eContourScale;
oContourValueVisible=eContourValueVisible;
oContourValueFormat=eContourValueFormat;
oContourValueFont=eContourValueFont;
oContourValueFontSize=eContourValueFontSize;
oContourValueDistance=eContourValueDistance;
oContourLevelsMaxN=eContourLevelsMaxN;
oTabBackgroundColor=eTabBackgroundColor;
oTabFrameVisible=eTabFrameVisible;
oTabFrameLineWidth=eTabFrameLineWidth;
oTabFrameColor=eTabFrameColor;
oTabFrameDash=eTabFrameDash;
oTabXLineVisible=eTabXLineVisible;
oTabXLineWidth=eTabXLineWidth;
oTabXLineColor=eTabXLineColor;
oTabXLineDash=eTabXLineDash;
oTabYLineVisible=eTabYLineVisible;
oTabYLineWidth=eTabYLineWidth;
oTabYLineColor=eTabYLineColor;
oTabYLineDash =eTabYLineDash ;
